@@ -13,7 +13,7 @@ from ccp_util import IPv4Obj
 ###
 ###   Use models_cisco.py at your own risk.  You have been warned :-)
 
-""" ciscoconfparse.py - Parse, Query, Build, and Modify IOS-style configurations
+""" models_cisco.py - Parse, Query, Build, and Modify IOS-style configurations
      Copyright (C) 2007-2014 David Michael Pennington
 
      This program is free software: you can redistribute it and/or modify
